#ifndef SPIINIT_H_
#define SPINIT_H

/*************************************************************************************************************************
									File Details
**************************************************************************************************************************
	File name 							: SPIInit.h
	
	Purpose								: This file has include file, macros, and function declaration corresponding to 
										  SPIInit.C file
	
	Author								: Mitesh Moonat & Harshit Gaharwar
	
	VDSP version used for testing		: VisualDSP++5.0, update 10
	
	Hardware used						: ADSP-21469, ADSP-21479, ADSP-21489, ADSP-21375, ADSP-21369, ADSP-21364,
										  ADSP-21262  EZ-Kits
	
	Connection details 					: See "main.C"
	
	Guidelines for change				: No changes require to this file for different SHARC processor or different FLASH 
**************************************************************************************************************************/

/*************************************************************************************************************************
									Include Files
**************************************************************************************************************************/

#include "math.h"
#include "sru.h"

//Processor specific definitons 
#if defined(__ADSP21262__)
	#include "def21262.h"
	#include "Cdef21262.h"

#elif defined (__ADSP21261__)
	#include "def21261.h"
	#include "Cdef21261.h"

#elif defined (__ADSP21266__)
	#include "def21266.h"
	#include "Cdef21266.h"

#elif defined (__ADSP21267__)
	#include "def21267.h"
	#include "Cdef21267.h"

#elif defined (__ADSP21362__)
	#include "def21362.h"
	#include "Cdef21362.h"

#elif defined (__ADSP21363__)
	#include "def21363.h"
	#include "Cdef21363.h"

#elif defined (__ADSP21364__)
	#include "def21364.h"
	#include "Cdef21364.h"

#elif defined (__ADSP21365__)
	#include "def21365.h"
	#include "Cdef21365.h"

#elif defined (__ADSP21366__)
	#include "def21366.h"
	#include "Cdef21366.h"

#elif defined (__ADSP21367__)
	#include "def21367.h"
	#include "Cdef21367.h"

#elif defined (__ADSP21368__)
	#include "def21368.h"
	#include "Cdef21368.h"

#elif defined (__ADSP21369__)
	#include "def21369.h"
	#include "Cdef21369.h"

#elif defined (__ADSP21375__)
	#include "def21375.h"
	#include "Cdef21375.h"

#elif defined (__ADSP21371__)
	#include "def21371h"
	#include "Cdef21371.h"

#elif defined (__ADSP21462__)
	#include "def21462.h"
	#include "Cdef21462.h"

#elif defined (__ADSP21465__)
	#include "def21465.h"
	#include "Cdef21465.h"

#elif defined (__ADSP21467__)
	#include "def21467.h"
	#include "Cdef21467.h"

#elif defined (__ADSP21469__)
	#include "def21469.h"
	#include "Cdef21469.h"

#elif defined (__ADSP21471__)
	#include "def21471.h"
	#include "Cdef21471.h"

#elif defined (__ADSP21472__)

	#include "def21472.h"
	#include "Cdef21472.h"

#elif defined (__ADSP21475__)
	#include "def21475.h"
	#include "Cdef21475.h"

#elif defined (__ADSP21478__)
	#include "def21478.h"
	#include "Cdef21478.h"

#elif defined (__ADSP21479__)
	#include "def21479.h"
	#include "Cdef21479.h"

#elif defined (__ADSP21481__)
	#include "def21481.h"
	#include "Cdef21481.h"

#elif defined (__ADSP21482__)
	#include "def21482.h"
	#include "Cdef21482.h"

#elif defined (__ADSP21483__)
	#include "def21483.h"
	#include "Cdef21483.h"

#elif defined (__ADSP21485__)
	#include "def21485.h"
	#include "Cdef21485.h"

#elif defined (__ADSP21486__)
	#include "def21486.h"
	#include "Cdef21486.h"

#elif defined (__ADSP21487__)
	#include "def21487.h"
	#include "Cdef21487.h"

#elif defined (__ADSP21488__)
	#include "def21488.h"
	#include "Cdef21488.h"

#elif defined (__ADSP21489__)
	#include "def21489.h"
	#include "Cdef21489.h"
	
#endif


#if defined(__ADSP21367__) || defined(__ADSP21368__) || defined(__ADSP21369__) || defined(__2137x__) || defined(__214xx__)
    
	#define SET_SS_LOW()	SRU(LOW, DPI_PB05_I);     //Drive the CS low
	
	#define SET_SS_HIGH()	SRU(HIGH, DPI_PB05_I);     //Drive the CS high
	
#else

	#define SET_SS_LOW()	asm("bit clr FLAGS 0x1;");      //Drive the CS low
	
	#define SET_SS_HIGH()	asm("bit set FLAGS 0x1;");      //Drive the CS high
	
	
#endif

#if defined(__2126x__)

	#define Wait_Till_External_Transfer_Complete()\
			int ii;\
			for(ii=0;ii<5000;ii++);
	
#else

	#define Wait_Till_External_Transfer_Complete()\
			while((*pSPISTAT&SPIFE)==0);
#endif


/*************************************************************************************************************************
									Function Declarations
**************************************************************************************************************************/
unsigned int SPI_Send_Receive_32bit(unsigned int uiTxBuff, bool bMSBF);
unsigned short SPI_Send_Receive_16bit(unsigned short uiTxBuff, bool bMSBF);
unsigned char SPI_Send_Receive_8bit(unsigned char uiTxBuff, bool bMSBF);
void SPI_Send_32bit(unsigned int uiTxBuff, bool bMSBF);
void SPI_Send_8bit(unsigned char uiTxBuff, bool bMSBF);
void SPI_Receive_Multiple_32bit(unsigned int* uiRxBuff, unsigned int uiCount, bool bMSBF);
void SPI_Receive_Multiple_8bit(unsigned char* uiRxBuff, unsigned int uiCount, bool bMSBF);
void SPI_Send_Multiple_8bit(unsigned char* uiTxBuff, unsigned int uiCount, bool bMSBF);
void SPI_Set_Baud_Rate(float fBaud, float fSCLK);
void SPI_Set_Slave_Select(bool bHigh);

/************************************************************************************************************************/
#endif

/**************************************** END OF FILE*********************************************************************/

